==> zeroc-ice_3.6.4.orig.tar.gz: ice-3.6.4/js/src/Ice/Communicator.js <==
// **********************************************************************
//
// Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

var Ice = require("../Ice/ModuleRegistry").Ice;
Ice.__M.require(module,
    [
        "../Ice/Class",
        "../Ice/Instance",
        "../Ice/Promise",
        "../Ice/UUID",
        "../Ice/AsyncResultBase"
    ]);

var Instance = Ice.Instance;
var Promise = Ice.Promise;

//
// Ice.Communicator
//
var Communicator = Ice.Class({
    __init__: function(initData)
    {
        this._instance = new Instance(initData);
    },
    //
    // Certain initialization tasks need to be completed after the
    // constructor.
    //
    finishSetup: function(promise)
    {
        this._instance.finishSetup(this, promise);
    },
    destroy: function()
    {
        return this._instance.destroy();
    },
    shutdown: function()
    {
        this._instance.objectAdapterFactory().shutdown();
    },
    waitForShutdown: function()
    {
        return this._instance.objectAdapterFactory().waitForShutdown();
    },
    isShutdown: function()
    {
        return this._instance.objectAdapterFactory().isShutdown();
    },
    stringToProxy: function(s)
    {
        return this._instance.proxyFactory().stringToProxy(s);
    },
    proxyToString: function(proxy)
    {
        return this._instance.proxyFactory().proxyToString(proxy);
    },
    propertyToProxy: function(s)
    {
        return this._instance.proxyFactory().propertyToProxy(s);
    },
    proxyToProperty: function(proxy, prefix)
    {
        return this._instance.proxyFactory().proxyToProperty(proxy, prefix);
    },
    stringToIdentity: function(s)
    {
        return this._instance.stringToIdentity(s);
    },
    identityToString: function(ident)
    {
        return this._instance.identityToString(ident);
    },
    createObjectAdapter: function(name)
    {
        var promise = new Ice.AsyncResultBase(this, "createObjectAdapter", this, null, null);
        this._instance.objectAdapterFactory().createObjectAdapter(name, null, promise);
        return promise;
    },
    createObjectAdapterWithEndpoints: function(name, endpoints)
    {
        if(name.length === 0)
        {
            name = Ice.generateUUID();
        }

        this.getProperties().setProperty(name + ".Endpoints", endpoints);
        var promise = new Ice.AsyncResultBase(this, "createObjectAdapterWithEndpoints", this, null, null);
        this._instance.objectAdapterFactory().createObjectAdapter(name, null, promise);
        return promise;
    },
    createObjectAdapterWithRouter: function(name, router)
    {
        if(name.length === 0)
        {
            name = Ice.generateUUID();
        }

        var promise = new Ice.AsyncResultBase(this, "createObjectAdapterWithRouter", this, null, null);

        //
        // We set the proxy properties here, although we still use the proxy supplied.
        //
        var properties = this.proxyToProperty(router, name + ".Router");
        for(var e = properties.entries; e !== null; e = e.next)
        {
            this.getProperties().setProperty(e.key, e.value);
        }

        this._instance.objectAdapterFactory().createObjectAdapter(name, router, promise);
        return promise;
    },
    addObjectFactory: function(factory, id)
    {
        this._instance.servantFactoryManager().add(factory, id);
    },
    findObjectFactory: function(id)
    {
        return this._instance.servantFactoryManager().find(id);
    },
    getImplicitContext: function()
    {
        return this._instance.getImplicitContext();
    },
    getProperties: function()
    {
        return this._instance.initializationData().properties;
    },
    getLogger: function()
    {
        return this._instance.initializationData().logger;
    },
    getDefaultRouter: function()
    {
        return this._instance.referenceFactory().getDefaultRouter();
    },
    setDefaultRouter: function(router)
    {
        this._instance.setDefaultRouter(router);
    },
    getDefaultLocator: function()
    {
        return this._instance.referenceFactory().getDefaultLocator();
    },
    setDefaultLocator: function(locator)
    {
        this._instance.setDefaultLocator(locator);
    },
    flushBatchRequests: function()
    {
        return this._instance.outgoingConnectionFactory().flushAsyncBatchRequests();
    }
});

Object.defineProperty(Communicator.prototype, "instance", {
    get: function() { return this._instance; }
});

Ice.Communicator = Communicator;
module.exports.Ice = Ice;

==> zeroc-ice_3.7.0.orig.tar.gz: ice-3.7.0/js/src/Ice/Communicator.js <==
// **********************************************************************
//
// Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

const Ice = require("../Ice/ModuleRegistry").Ice;
Ice._ModuleRegistry.require(module,
    [
        "../Ice/Instance",
        "../Ice/UUID",
        "../Ice/AsyncResultBase"
    ]);

const Instance = Ice.Instance;

//
// Ice.Communicator
//
class Communicator
{
    constructor(initData)
    {
        this._instance = new Instance(initData);
    }

    //
    // Certain initialization tasks need to be completed after the
    // constructor.
    //
    finishSetup(promise)
    {
        this._instance.finishSetup(this, promise);
    }

    destroy()
    {
        return this._instance.destroy();
    }

    shutdown()
    {
        this._instance.objectAdapterFactory().shutdown();
    }

    waitForShutdown()
    {
        return this._instance.objectAdapterFactory().waitForShutdown();
    }

    isShutdown()
    {
        return this._instance.objectAdapterFactory().isShutdown();
    }

    stringToProxy(s)
    {
        return this._instance.proxyFactory().stringToProxy(s);
    }

    proxyToString(proxy)
    {
        return this._instance.proxyFactory().proxyToString(proxy);
    }

    propertyToProxy(s)
    {
        return this._instance.proxyFactory().propertyToProxy(s);
    }

    proxyToProperty(proxy, prefix)
    {
        return this._instance.proxyFactory().proxyToProperty(proxy, prefix);
    }

    stringToIdentity(s)
    {
        return Ice.stringToIdentity(s);
    }

    identityToString(ident)
    {
        return Ice.identityToString(ident, this._instance.toStringMode());
    }

    createObjectAdapter(name)
    {
        const promise = new Ice.AsyncResultBase(this, "createObjectAdapter", this, null, null);
        this._instance.objectAdapterFactory().createObjectAdapter(name, null, promise);
        return promise;
    }

    createObjectAdapterWithEndpoints(name, endpoints)
    {
        if(name.length === 0)
        {
            name = Ice.generateUUID();
        }

        this.getProperties().setProperty(name + ".Endpoints", endpoints);
        const promise = new Ice.AsyncResultBase(this, "createObjectAdapterWithEndpoints", this, null, null);
        this._instance.objectAdapterFactory().createObjectAdapter(name, null, promise);
        return promise;
    }

    createObjectAdapterWithRouter(name, router)
    {
        if(name.length === 0)
        {
            name = Ice.generateUUID();
        }

        const promise = new Ice.AsyncResultBase(this, "createObjectAdapterWithRouter", this, null, null);

        //
        // We set the proxy properties here, although we still use the proxy supplied.
        //
        this.proxyToProperty(router, name + ".Router").forEach((value, key) =>
            {
                this.getProperties().setProperty(key, value);
            });

        this._instance.objectAdapterFactory().createObjectAdapter(name, router, promise);
        return promise;
    }

    addObjectFactory(factory, id)
    {
        this._instance.addObjectFactory(factory, id);
    }

    findObjectFactory(id)
    {
        return this._instance.findObjectFactory(id);
    }

    getValueFactoryManager()
    {
        return this._instance.initializationData().valueFactoryManager;
    }

    getImplicitContext()
    {
        return this._instance.getImplicitContext();
    }

    getProperties()
    {
        return this._instance.initializationData().properties;
    }

    getLogger()
    {
        return this._instance.initializationData().logger;
    }

    getDefaultRouter()
    {
        return this._instance.referenceFactory().getDefaultRouter();
    }

    setDefaultRouter(router)
    {
        this._instance.setDefaultRouter(router);
    }

    getDefaultLocator()
    {
        return this._instance.referenceFactory().getDefaultLocator();
    }

    setDefaultLocator(locator)
    {
        this._instance.setDefaultLocator(locator);
    }

    flushBatchRequests()
    {
        return this._instance.outgoingConnectionFactory().flushAsyncBatchRequests();
    }

    get instance()
    {
        return this._instance;
    }
}

Ice.Communicator = Communicator;
module.exports.Ice = Ice;
